#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'easy_type'

# TODO: Add documentation
Puppet::Type.newtype(:fact_cache) do
  include EasyType

  def self.module_name
    'easy_type'
  end

  desc <<-DESC
  Puppet type to clear the facter cache.
  DESC

  def cache_file
    "#{self.class.cache_dir}/#{name}"
  end

  def self.cache_dir
    kernel = Facter.value(:kernel)
    case kernel
    when 'Linux'
      '/opt/puppetlabs/facter/cache/cached_facts'
    when 'windows'
      'C:/ProgramData/PuppetLabs/facter/cache/cached_facts'      
    else
      fail "'#{kernel}' not (yet) supported."
    end
  end

  to_get_raw_resources do
    return [] unless Dir.exist?(cache_dir)

    cached_facts = Dir.entries(cache_dir)[2..-1]
    cached_facts.collect { |e| { :name => e } }
  end

  on_destroy do
    return nil if refreshonly.to_s == 'true'

    Puppet.debug "Clearing cache for fact '#{name}'..."
    delete_cache_file
    nil
  end

  # On refresh we want to clear the fact cache. We do this by removing the
  # cached file
  on_notify do
    Puppet.debug "Notification received on fact config #{name}; clearing cache..."
    delete_cache_file
  end

  def delete_cache_file
    File.delete(cache_file) if File.exist?(cache_file)
  end

  property  :ensure
  parameter :name
  parameter :refreshonly
end
