# 
# @summary Ensure the EM licenses are activated at the right point during a Puppet run. 
# 
# Best thing is add this class in your site.pp. Because it makes sure the entitlements files are 
# copied in the specified stage, the entitlements are available when the EM modules start their work.
#
# @param activate_node_groups
#        Activate the mechanism to register license nodes in a PE node group
#
# @param run_stage
#        The Puppet stage at which the puppet license files will be
#
#
# See the file "LICENSE" for the full license governing this code.
#
class easy_type::license::activate(
  Boolean             $activate_node_groups = true,
  Optional[String[1]] $run_stage            = 'setup',
)
{
  require 'stdlib'

  if $activate_node_groups {
    easy_type::activate_node_groups()
  }

  class { '::easy_type::license::available':
    stage => $run_stage,
  }
}
